/**
 * @file		libsd.h
 * @brief		Default compile-time configuration of library sd
 * @ingroup		config_compile, libsd
 * @version		$Revision: 262 $
 *
 * $Id: libSD.h 262 2007-11-15 09:02:47Z blywis@PCPOOL.MI.FU-BERLIN.DE $
 */

/**
 * @brief	Library Initialiser
 * @internal
 */
void libSD_Init();

/**
 * @addtogroup	config_compile
 * @{
 */
#ifndef SD_READ_BYTE
/**
 * @brief Enable read function optimized for single bytes
 * @ingroup	conf
 * @since	libsd 0.2
 */
#define SD_READ_BYTE			0
#endif

#ifndef SD_READ_ANY
/**
 * @brief Enable read function optimized for read-function for any/unknown size
 * @ingroup	conf
 * @since	libsd 0.2
 */
#define	SD_READ_ANY				1
#endif


#ifndef SD_INFO
/**
 * @brief Enable functions for reading and interpreting informative card registers
 * @ingroup	conf
 * @since	libsd 0.2
 */
#define SD_INFO					0
#endif

#ifndef SD_WRITE
/**
 * @brief Enable writing functionality
 * @ingroup	conf
 * @since	libsd 0.2
 */
#define SD_WRITE				1
#endif

#ifndef SD_FIND_FILE
/**
 * @brief Enable file-system independent (raw) search function
 * @ingroup	conf
 * @since	libsd 0.2
 */
#define SD_FIND_FILE			0
#endif

#ifndef SD_ERASE
/**
 * @brief Enable block-erase functions
 * @ingroup	conf
 * @since	libsd 0.2
 */
#define SD_ERASE				0			
#endif

#ifndef SD_CACHE
/**
 * @brief Enable caching for write and/or read mode.
 * Needs 512 bytes of RAM but enables block-independant write functionality.
 * @ingroup	conf
 * @since	libsd 0.2
 */
#define	SD_CACHE				0
#endif

#ifndef SPI_WRITE
/**
 * @brief Enable SPI interface write functionality
 * @ingroup	conf
 * @since	libsd 0.2
 */
#define SPI_WRITE				SD_WRITE
#endif

#ifndef SPI_DMA_READ
/**
 * @brief Enable DMA read support
 * @ingroup	conf
 * @since	libsd 0.2
 *
 * Use DMA transfer for SPI read. Cost is ~40 bytes code size increase.
 * DMA reading is implemented as blocking so the results are available
 * when the read function returns.
 */
#define SPI_DMA_READ			0
#endif

#if !defined SPI_DMA_WRITE && SPI_WRITE
/**
 * @brief DMA write support
 * @ingroup	conf
 * @since	libsd 0.2
 *
 * Use DMA transfer for SPI write. Cost is ~40 bytes code size increase. Note that DMA writes are non-blocking
 * and run in the background. Before modifying or reusing the transfer buffer the write
 * operation must be completed. Run Spi_dma_flush to delay until the DMA transfer has finished
 * and complete the write operation.
 */
#define SPI_DMA_WRITE			0
#endif
///@}

